# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
import sys
from typing import Any, Optional, TYPE_CHECKING, cast

from azure.core.pipeline import policies
from azure.core.rest import HttpRequest, HttpResponse
from azure.core.settings import settings
from azure.mgmt.core import ARMPipelineClient
from azure.mgmt.core.policies import ARMAutoResourceProviderRegistrationPolicy
from azure.mgmt.core.tools import get_arm_endpoints

from ._configuration import CognitiveServicesManagementClientConfiguration
from ._utils.serialization import Deserializer, Serializer
from .operations import (
    AccountCapabilityHostsOperations,
    AccountConnectionsOperations,
    AccountsOperations,
    AgentApplicationsOperations,
    AgentDeploymentsOperations,
    CommitmentPlansOperations,
    CommitmentTiersOperations,
    ComputeOperationsOperations,
    ComputesOperations,
    DefenderForAISettingsOperations,
    DeletedAccountsOperations,
    DeploymentsOperations,
    EncryptionScopesOperations,
    LocationBasedModelCapacitiesOperations,
    ManagedComputeCapacitiesOperations,
    ManagedComputeDeploymentsOperations,
    ManagedComputeUsagesOperationGroupOperations,
    ManagedNetworkProvisionsOperations,
    ManagedNetworkSettingsOperations,
    ModelCapacitiesOperations,
    ModelsOperations,
    NetworkSecurityPerimeterConfigurationsOperations,
    Operations,
    OutboundRuleOperations,
    OutboundRulesOperations,
    PrivateEndpointConnectionsOperations,
    PrivateLinkResourcesOperations,
    ProjectCapabilityHostsOperations,
    ProjectConnectionsOperations,
    ProjectsOperations,
    QuotaTiersOperations,
    RaiBlocklistItemsOperations,
    RaiBlocklistsOperations,
    RaiContentFiltersOperations,
    RaiExternalSafetyProviderOperations,
    RaiExternalSafetyProvidersOperations,
    RaiPoliciesOperations,
    RaiToolLabelsOperations,
    RaiTopicsOperations,
    ResourceSkusOperations,
    SubscriptionRaiPolicyOperations,
    TestRaiExternalSafetyProviderOperations,
    UsagesOperations,
    WorkbenchesOperations,
    _CognitiveServicesManagementClientOperationsMixin,
)

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self  # type: ignore

if TYPE_CHECKING:
    from azure.core import AzureClouds
    from azure.core.credentials import TokenCredential


class CognitiveServicesManagementClient(
    _CognitiveServicesManagementClientOperationsMixin
):  # pylint: disable=too-many-instance-attributes
    """Cognitive Services Management Client.

    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.cognitiveservices.operations.Operations
    :ivar accounts: AccountsOperations operations
    :vartype accounts: azure.mgmt.cognitiveservices.operations.AccountsOperations
    :ivar deleted_accounts: DeletedAccountsOperations operations
    :vartype deleted_accounts: azure.mgmt.cognitiveservices.operations.DeletedAccountsOperations
    :ivar private_endpoint_connections: PrivateEndpointConnectionsOperations operations
    :vartype private_endpoint_connections:
     azure.mgmt.cognitiveservices.operations.PrivateEndpointConnectionsOperations
    :ivar deployments: DeploymentsOperations operations
    :vartype deployments: azure.mgmt.cognitiveservices.operations.DeploymentsOperations
    :ivar commitment_plans: CommitmentPlansOperations operations
    :vartype commitment_plans: azure.mgmt.cognitiveservices.operations.CommitmentPlansOperations
    :ivar encryption_scopes: EncryptionScopesOperations operations
    :vartype encryption_scopes: azure.mgmt.cognitiveservices.operations.EncryptionScopesOperations
    :ivar rai_policies: RaiPoliciesOperations operations
    :vartype rai_policies: azure.mgmt.cognitiveservices.operations.RaiPoliciesOperations
    :ivar subscription_rai_policy: SubscriptionRaiPolicyOperations operations
    :vartype subscription_rai_policy:
     azure.mgmt.cognitiveservices.operations.SubscriptionRaiPolicyOperations
    :ivar rai_blocklist_items: RaiBlocklistItemsOperations operations
    :vartype rai_blocklist_items:
     azure.mgmt.cognitiveservices.operations.RaiBlocklistItemsOperations
    :ivar rai_blocklists: RaiBlocklistsOperations operations
    :vartype rai_blocklists: azure.mgmt.cognitiveservices.operations.RaiBlocklistsOperations
    :ivar rai_topics: RaiTopicsOperations operations
    :vartype rai_topics: azure.mgmt.cognitiveservices.operations.RaiTopicsOperations
    :ivar rai_tool_labels: RaiToolLabelsOperations operations
    :vartype rai_tool_labels: azure.mgmt.cognitiveservices.operations.RaiToolLabelsOperations
    :ivar rai_content_filters: RaiContentFiltersOperations operations
    :vartype rai_content_filters:
     azure.mgmt.cognitiveservices.operations.RaiContentFiltersOperations
    :ivar network_security_perimeter_configurations:
     NetworkSecurityPerimeterConfigurationsOperations operations
    :vartype network_security_perimeter_configurations:
     azure.mgmt.cognitiveservices.operations.NetworkSecurityPerimeterConfigurationsOperations
    :ivar defender_for_ai_settings: DefenderForAISettingsOperations operations
    :vartype defender_for_ai_settings:
     azure.mgmt.cognitiveservices.operations.DefenderForAISettingsOperations
    :ivar projects: ProjectsOperations operations
    :vartype projects: azure.mgmt.cognitiveservices.operations.ProjectsOperations
    :ivar project_connections: ProjectConnectionsOperations operations
    :vartype project_connections:
     azure.mgmt.cognitiveservices.operations.ProjectConnectionsOperations
    :ivar project_capability_hosts: ProjectCapabilityHostsOperations operations
    :vartype project_capability_hosts:
     azure.mgmt.cognitiveservices.operations.ProjectCapabilityHostsOperations
    :ivar quota_tiers: QuotaTiersOperations operations
    :vartype quota_tiers: azure.mgmt.cognitiveservices.operations.QuotaTiersOperations
    :ivar agent_applications: AgentApplicationsOperations operations
    :vartype agent_applications:
     azure.mgmt.cognitiveservices.operations.AgentApplicationsOperations
    :ivar managed_compute_deployments: ManagedComputeDeploymentsOperations operations
    :vartype managed_compute_deployments:
     azure.mgmt.cognitiveservices.operations.ManagedComputeDeploymentsOperations
    :ivar compute_operations: ComputeOperationsOperations operations
    :vartype compute_operations:
     azure.mgmt.cognitiveservices.operations.ComputeOperationsOperations
    :ivar managed_compute_usages_operation_group: ManagedComputeUsagesOperationGroupOperations
     operations
    :vartype managed_compute_usages_operation_group:
     azure.mgmt.cognitiveservices.operations.ManagedComputeUsagesOperationGroupOperations
    :ivar computes: ComputesOperations operations
    :vartype computes: azure.mgmt.cognitiveservices.operations.ComputesOperations
    :ivar workbenches: WorkbenchesOperations operations
    :vartype workbenches: azure.mgmt.cognitiveservices.operations.WorkbenchesOperations
    :ivar managed_compute_capacities: ManagedComputeCapacitiesOperations operations
    :vartype managed_compute_capacities:
     azure.mgmt.cognitiveservices.operations.ManagedComputeCapacitiesOperations
    :ivar private_link_resources: PrivateLinkResourcesOperations operations
    :vartype private_link_resources:
     azure.mgmt.cognitiveservices.operations.PrivateLinkResourcesOperations
    :ivar test_rai_external_safety_provider: TestRaiExternalSafetyProviderOperations operations
    :vartype test_rai_external_safety_provider:
     azure.mgmt.cognitiveservices.operations.TestRaiExternalSafetyProviderOperations
    :ivar rai_external_safety_provider: RaiExternalSafetyProviderOperations operations
    :vartype rai_external_safety_provider:
     azure.mgmt.cognitiveservices.operations.RaiExternalSafetyProviderOperations
    :ivar rai_external_safety_providers: RaiExternalSafetyProvidersOperations operations
    :vartype rai_external_safety_providers:
     azure.mgmt.cognitiveservices.operations.RaiExternalSafetyProvidersOperations
    :ivar account_connections: AccountConnectionsOperations operations
    :vartype account_connections:
     azure.mgmt.cognitiveservices.operations.AccountConnectionsOperations
    :ivar account_capability_hosts: AccountCapabilityHostsOperations operations
    :vartype account_capability_hosts:
     azure.mgmt.cognitiveservices.operations.AccountCapabilityHostsOperations
    :ivar outbound_rule: OutboundRuleOperations operations
    :vartype outbound_rule: azure.mgmt.cognitiveservices.operations.OutboundRuleOperations
    :ivar managed_network_settings: ManagedNetworkSettingsOperations operations
    :vartype managed_network_settings:
     azure.mgmt.cognitiveservices.operations.ManagedNetworkSettingsOperations
    :ivar outbound_rules: OutboundRulesOperations operations
    :vartype outbound_rules: azure.mgmt.cognitiveservices.operations.OutboundRulesOperations
    :ivar managed_network_provisions: ManagedNetworkProvisionsOperations operations
    :vartype managed_network_provisions:
     azure.mgmt.cognitiveservices.operations.ManagedNetworkProvisionsOperations
    :ivar agent_deployments: AgentDeploymentsOperations operations
    :vartype agent_deployments: azure.mgmt.cognitiveservices.operations.AgentDeploymentsOperations
    :ivar resource_skus: ResourceSkusOperations operations
    :vartype resource_skus: azure.mgmt.cognitiveservices.operations.ResourceSkusOperations
    :ivar usages: UsagesOperations operations
    :vartype usages: azure.mgmt.cognitiveservices.operations.UsagesOperations
    :ivar commitment_tiers: CommitmentTiersOperations operations
    :vartype commitment_tiers: azure.mgmt.cognitiveservices.operations.CommitmentTiersOperations
    :ivar models: ModelsOperations operations
    :vartype models: azure.mgmt.cognitiveservices.operations.ModelsOperations
    :ivar location_based_model_capacities: LocationBasedModelCapacitiesOperations operations
    :vartype location_based_model_capacities:
     azure.mgmt.cognitiveservices.operations.LocationBasedModelCapacitiesOperations
    :ivar model_capacities: ModelCapacitiesOperations operations
    :vartype model_capacities: azure.mgmt.cognitiveservices.operations.ModelCapacitiesOperations
    :param credential: Credential used to authenticate requests to the service. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service host. Default value is None.
    :type base_url: str
    :keyword cloud_setting: The cloud setting for which to get the ARM endpoint. Default value is
     None.
    :paramtype cloud_setting: ~azure.core.AzureClouds
    :keyword api_version: The API version to use for this operation. Known values are
     "2026-05-15-preview" and None. Default value is None. If not set, the operation's default API
     version will be used. Note that overriding this default value may result in unsupported
     behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: Optional[str] = None,
        *,
        cloud_setting: Optional["AzureClouds"] = None,
        **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        _cloud = cloud_setting or settings.current.azure_cloud  # type: ignore
        _endpoints = get_arm_endpoints(_cloud)
        if not base_url:
            base_url = _endpoints["resource_manager"]
        credential_scopes = kwargs.pop("credential_scopes", _endpoints["credential_scopes"])
        self._config = CognitiveServicesManagementClientConfiguration(
            credential=credential,
            subscription_id=subscription_id,
            base_url=cast(str, base_url),
            cloud_setting=cloud_setting,
            credential_scopes=credential_scopes,
            **kwargs
        )

        _policies = kwargs.pop("policies", None)
        if _policies is None:
            _policies = [
                policies.RequestIdPolicy(**kwargs),
                self._config.headers_policy,
                self._config.user_agent_policy,
                self._config.proxy_policy,
                policies.ContentDecodePolicy(**kwargs),
                ARMAutoResourceProviderRegistrationPolicy(),
                self._config.redirect_policy,
                self._config.retry_policy,
                self._config.authentication_policy,
                self._config.custom_hook_policy,
                self._config.logging_policy,
                policies.DistributedTracingPolicy(**kwargs),
                policies.SensitiveHeaderCleanupPolicy(**kwargs) if self._config.redirect_policy else None,
                self._config.http_logging_policy,
            ]
        self._client: ARMPipelineClient = ARMPipelineClient(base_url=cast(str, _endpoint), policies=_policies, **kwargs)

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.accounts = AccountsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.deleted_accounts = DeletedAccountsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_endpoint_connections = PrivateEndpointConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.deployments = DeploymentsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.commitment_plans = CommitmentPlansOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.encryption_scopes = EncryptionScopesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_policies = RaiPoliciesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.subscription_rai_policy = SubscriptionRaiPolicyOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_blocklist_items = RaiBlocklistItemsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_blocklists = RaiBlocklistsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.rai_topics = RaiTopicsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.rai_tool_labels = RaiToolLabelsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.rai_content_filters = RaiContentFiltersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.network_security_perimeter_configurations = NetworkSecurityPerimeterConfigurationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.defender_for_ai_settings = DefenderForAISettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.projects = ProjectsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.project_connections = ProjectConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.project_capability_hosts = ProjectCapabilityHostsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.quota_tiers = QuotaTiersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.agent_applications = AgentApplicationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.managed_compute_deployments = ManagedComputeDeploymentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.compute_operations = ComputeOperationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.managed_compute_usages_operation_group = ManagedComputeUsagesOperationGroupOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.computes = ComputesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.workbenches = WorkbenchesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.managed_compute_capacities = ManagedComputeCapacitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_link_resources = PrivateLinkResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.test_rai_external_safety_provider = TestRaiExternalSafetyProviderOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_external_safety_provider = RaiExternalSafetyProviderOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_external_safety_providers = RaiExternalSafetyProvidersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.account_connections = AccountConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.account_capability_hosts = AccountCapabilityHostsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.outbound_rule = OutboundRuleOperations(self._client, self._config, self._serialize, self._deserialize)
        self.managed_network_settings = ManagedNetworkSettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.outbound_rules = OutboundRulesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.managed_network_provisions = ManagedNetworkProvisionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.agent_deployments = AgentDeploymentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.resource_skus = ResourceSkusOperations(self._client, self._config, self._serialize, self._deserialize)
        self.usages = UsagesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.commitment_tiers = CommitmentTiersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.models = ModelsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.location_based_model_capacities = LocationBasedModelCapacitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.model_capacities = ModelCapacitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )

    def send_request(self, request: HttpRequest, *, stream: bool = False, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client.send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.base_url", self._config.base_url, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, stream=stream, **kwargs)  # type: ignore

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> Self:
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details: Any) -> None:
        self._client.__exit__(*exc_details)



# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import AccountsOperations  # type: ignore
from ._operations import DeletedAccountsOperations  # type: ignore
from ._operations import PrivateEndpointConnectionsOperations  # type: ignore
from ._operations import DeploymentsOperations  # type: ignore
from ._operations import CommitmentPlansOperations  # type: ignore
from ._operations import EncryptionScopesOperations  # type: ignore
from ._operations import RaiPoliciesOperations  # type: ignore
from ._operations import SubscriptionRaiPolicyOperations  # type: ignore
from ._operations import RaiBlocklistItemsOperations  # type: ignore
from ._operations import RaiBlocklistsOperations  # type: ignore
from ._operations import RaiTopicsOperations  # type: ignore
from ._operations import RaiToolLabelsOperations  # type: ignore
from ._operations import RaiContentFiltersOperations  # type: ignore
from ._operations import NetworkSecurityPerimeterConfigurationsOperations  # type: ignore
from ._operations import DefenderForAISettingsOperations  # type: ignore
from ._operations import ProjectsOperations  # type: ignore
from ._operations import ProjectConnectionsOperations  # type: ignore
from ._operations import ProjectCapabilityHostsOperations  # type: ignore
from ._operations import QuotaTiersOperations  # type: ignore
from ._operations import AgentApplicationsOperations  # type: ignore
from ._operations import ManagedComputeDeploymentsOperations  # type: ignore
from ._operations import ComputeOperationsOperations  # type: ignore
from ._operations import ManagedComputeUsagesOperationGroupOperations  # type: ignore
from ._operations import ComputesOperations  # type: ignore
from ._operations import WorkbenchesOperations  # type: ignore
from ._operations import ManagedComputeCapacitiesOperations  # type: ignore
from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import TestRaiExternalSafetyProviderOperations  # type: ignore
from ._operations import RaiExternalSafetyProviderOperations  # type: ignore
from ._operations import RaiExternalSafetyProvidersOperations  # type: ignore
from ._operations import AccountConnectionsOperations  # type: ignore
from ._operations import AccountCapabilityHostsOperations  # type: ignore
from ._operations import OutboundRuleOperations  # type: ignore
from ._operations import ManagedNetworkSettingsOperations  # type: ignore
from ._operations import OutboundRulesOperations  # type: ignore
from ._operations import ManagedNetworkProvisionsOperations  # type: ignore
from ._operations import AgentDeploymentsOperations  # type: ignore
from ._operations import ResourceSkusOperations  # type: ignore
from ._operations import UsagesOperations  # type: ignore
from ._operations import CommitmentTiersOperations  # type: ignore
from ._operations import ModelsOperations  # type: ignore
from ._operations import LocationBasedModelCapacitiesOperations  # type: ignore
from ._operations import ModelCapacitiesOperations  # type: ignore
from ._operations import _CognitiveServicesManagementClientOperationsMixin  # type: ignore # pylint: disable=unused-import

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "AccountsOperations",
    "DeletedAccountsOperations",
    "PrivateEndpointConnectionsOperations",
    "DeploymentsOperations",
    "CommitmentPlansOperations",
    "EncryptionScopesOperations",
    "RaiPoliciesOperations",
    "SubscriptionRaiPolicyOperations",
    "RaiBlocklistItemsOperations",
    "RaiBlocklistsOperations",
    "RaiTopicsOperations",
    "RaiToolLabelsOperations",
    "RaiContentFiltersOperations",
    "NetworkSecurityPerimeterConfigurationsOperations",
    "DefenderForAISettingsOperations",
    "ProjectsOperations",
    "ProjectConnectionsOperations",
    "ProjectCapabilityHostsOperations",
    "QuotaTiersOperations",
    "AgentApplicationsOperations",
    "ManagedComputeDeploymentsOperations",
    "ComputeOperationsOperations",
    "ManagedComputeUsagesOperationGroupOperations",
    "ComputesOperations",
    "WorkbenchesOperations",
    "ManagedComputeCapacitiesOperations",
    "PrivateLinkResourcesOperations",
    "TestRaiExternalSafetyProviderOperations",
    "RaiExternalSafetyProviderOperations",
    "RaiExternalSafetyProvidersOperations",
    "AccountConnectionsOperations",
    "AccountCapabilityHostsOperations",
    "OutboundRuleOperations",
    "ManagedNetworkSettingsOperations",
    "OutboundRulesOperations",
    "ManagedNetworkProvisionsOperations",
    "AgentDeploymentsOperations",
    "ResourceSkusOperations",
    "UsagesOperations",
    "CommitmentTiersOperations",
    "ModelsOperations",
    "LocationBasedModelCapacitiesOperations",
    "ModelCapacitiesOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# pylint: disable=line-too-long,useless-suppression
# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 14
# Methods Covered : 14
# Examples Total  : 15
# Examples Tested : 13
# Coverage %      : 87
# ----------------------

import unittest

import azure.mgmt.cognitiveservices
from devtools_testutils import AzureMgmtTestCase, ResourceGroupPreparer

AZURE_LOCATION = "eastus"


class MgmtCognitiveServicesTest(AzureMgmtTestCase):

    def setUp(self):
        super(MgmtCognitiveServicesTest, self).setUp()
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.cognitiveservices.CognitiveServicesManagementClient)

    @unittest.skip("hard to test")
    @ResourceGroupPreparer(location=AZURE_LOCATION)
    def test_cognitiveservices(self, resource_group):

        SUBSCRIPTION_ID = self.settings.SUBSCRIPTION_ID
        RESOURCE_GROUP = resource_group.name
        ACCOUNT_NAME = "myAccount"
        LOCATION = "myLocation"

        # /Accounts/put/Create Account Min[put]
        BODY = {
            "location": "West US",
            "kind": "CognitiveServices",
            "sku": {"name": "S0"},
            "identity": {"type": "SystemAssigned"},
        }
        result = self.mgmt_client.accounts.create(
            resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME, account=BODY
        )

        # /Accounts/put/Create Account[put]
        BODY = {
            "location": "West US",
            "kind": "Emotion",
            "sku": {"name": "S0"},
            "properties": {
                "encryption": {
                    "key_vault_properties": {
                        "key_name": "KeyName",
                        "key_version": "891CF236-D241-4738-9462-D506AF493DFA",
                        "key_vault_uri": "https://pltfrmscrts-use-pc-dev.vault.azure.net/",
                    },
                    "key_source": "Microsoft.KeyVault",
                },
                "user_owned_storage": [
                    {
                        "resource_id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Storage/storageAccountsfelixwatest"
                    }
                ],
            },
            "identity": {"type": "SystemAssigned"},
        }
        # result = self.mgmt_client.accounts.create(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME, account=BODY)

        # /Accounts/get/Get Usages[get]
        result = self.mgmt_client.accounts.get_usages(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME)

        # /Accounts/get/List SKUs[get]
        result = self.mgmt_client.accounts.list_skus(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME)

        # /Accounts/get/Get Account[get]
        result = self.mgmt_client.accounts.get_properties(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME)

        # /Accounts/get/List Accounts by Resource Group[get]
        result = self.mgmt_client.accounts.list_by_resource_group(resource_group_name=RESOURCE_GROUP)

        # /Accounts/get/List Accounts by Subscription[get]
        result = self.mgmt_client.accounts.list()

        # /ResourceSkus/get/Regenerate Keys[get]
        result = self.mgmt_client.resource_skus.list()

        # /Operations/get/Get Operations[get]
        result = self.mgmt_client.operations.list()

        # /Accounts/post/Regenerate Keys[post]
        result = self.mgmt_client.accounts.regenerate_key(
            resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME, key_name="Key2"
        )

        # /Accounts/post/List Keys[post]
        result = self.mgmt_client.accounts.list_keys(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME)

        # /Accounts/patch/Update Account[patch]
        BODY = {"sku": {"name": "S2"}}
        # result = self.mgmt_client.accounts.update(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME, account=BODY)

        # //post/Check SKU Availability[post]
        SKUS = ["S0"]
        result = self.mgmt_client.check_sku_availability(
            location="eastus", skus=SKUS, kind="Face", type="Microsoft.CognitiveServices/accounts"
        )

        # /Accounts/delete/Delete Account[delete]
        result = self.mgmt_client.accounts.delete(resource_group_name=RESOURCE_GROUP, account_name=ACCOUNT_NAME)


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AADAuthTypeConnectionProperties,
    AbusePenalty,
    AccessKeyAuthTypeConnectionProperties,
    Account,
    AccountKeyAuthTypeConnectionProperties,
    AccountModel,
    AccountProperties,
    AccountSku,
    AccountSkuListResult,
    AgentApplication,
    AgentDeployment,
    AgentDeploymentProperties,
    AgentProtocolVersion,
    AgentReference,
    AgentReferenceProperties,
    AgentReferenceResourceArmPaginatedResult,
    AgenticApplicationProperties,
    ApiKeyAuthConnectionProperties,
    ApiKeys,
    ApiProperties,
    ApplicationAuthorizationPolicy,
    ApplicationTrafficRoutingPolicy,
    AssignedIdentity,
    BillingMeterInfo,
    CalculateModelCapacityParameter,
    CalculateModelCapacityResult,
    CalculateModelCapacityResultEstimatedCapacity,
    CallRateLimit,
    CapabilityHost,
    CapabilityHostProperties,
    CapacityConfig,
    ChannelsBuiltInAuthorizationPolicy,
    CheckDomainAvailabilityParameter,
    CheckSkuAvailabilityParameter,
    ClusterComputeProperties,
    CommitmentCost,
    CommitmentPeriod,
    CommitmentPlan,
    CommitmentPlanAccountAssociation,
    CommitmentPlanAccountAssociationProperties,
    CommitmentPlanAssociation,
    CommitmentPlanProperties,
    CommitmentQuota,
    CommitmentTier,
    Compute,
    ComputeOperationStatus,
    ComputeOperationStatusProperties,
    ComputeProperties,
    ConnectionAccessKey,
    ConnectionAccountKey,
    ConnectionApiKey,
    ConnectionManagedIdentity,
    ConnectionOAuth2,
    ConnectionPersonalAccessToken,
    ConnectionPropertiesV2,
    ConnectionPropertiesV2BasicResource,
    ConnectionServicePrincipal,
    ConnectionSharedAccessSignature,
    ConnectionUpdateContent,
    ConnectionUsernamePassword,
    ConnectivityEndpoints,
    ContainerInstanceComputeProperties,
    CustomBlocklistConfig,
    CustomKeys,
    CustomKeysConnectionProperties,
    DefenderForAISetting,
    DefenderForAISettingProperties,
    Deployment,
    DeploymentCapacitySettings,
    DeploymentModel,
    DeploymentPolicyEvaluationResult,
    DeploymentProperties,
    DeploymentRouting,
    DeploymentScaleSettings,
    DeploymentSizeCapacity,
    DeploymentSpeculativeDecoding,
    DomainAvailability,
    Encryption,
    EncryptionScope,
    EncryptionScopeProperties,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorResponse,
    EvaluateDeploymentPoliciesDeployment,
    EvaluateDeploymentPoliciesDeploymentProperties,
    EvaluateDeploymentPoliciesRequest,
    EvaluateDeploymentPoliciesResponse,
    FoundryAutoUpgrade,
    FqdnOutboundRule,
    HostedAgentDeployment,
    Identity,
    IpRule,
    KeyVaultProperties,
    ManagedAgentDeployment,
    ManagedComputeCapacity,
    ManagedComputeCapacityProperties,
    ManagedComputeDeployment,
    ManagedComputeDeploymentInfo,
    ManagedComputeDeploymentProperties,
    ManagedComputeDeploymentProvisioningDetails,
    ManagedComputeDeploymentRoutes,
    ManagedComputeUsage,
    ManagedIdentityAuthTypeConnectionProperties,
    ManagedNetworkProvisionOptions,
    ManagedNetworkProvisionStatus,
    ManagedNetworkSettings,
    ManagedNetworkSettingsBasicResource,
    ManagedNetworkSettingsEx,
    ManagedNetworkSettingsProperties,
    ManagedNetworkSettingsPropertiesBasicResource,
    MetricName,
    Model,
    ModelCapacityCalculatorWorkload,
    ModelCapacityCalculatorWorkloadRequestParam,
    ModelCapacityListResultValueItem,
    ModelDeprecationInfo,
    ModelSku,
    ModelSkuCapacityProperties,
    MultiRegionSettings,
    NetworkInjection,
    NetworkRuleSet,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterAccessRule,
    NetworkSecurityPerimeterAccessRuleProperties,
    NetworkSecurityPerimeterAccessRulePropertiesSubscriptionsItem,
    NetworkSecurityPerimeterConfiguration,
    NetworkSecurityPerimeterConfigurationAssociationInfo,
    NetworkSecurityPerimeterConfigurationProperties,
    NetworkSecurityPerimeterProfileInfo,
    NoneAuthTypeConnectionProperties,
    OAuth2AuthTypeConnectionProperties,
    Operation,
    OperationDisplay,
    OrganizationSharedBuiltInAuthorizationPolicy,
    OutboundRule,
    OutboundRuleBasicResource,
    PATAuthTypeConnectionProperties,
    PatchResourceSku,
    PatchResourceTags,
    PatchResourceTagsAndSku,
    PolicyAssignmentEvaluationDetails,
    PolicyExpressionEvaluationDetails,
    Pool,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionListResult,
    PrivateEndpointConnectionProperties,
    PrivateEndpointOutboundRule,
    PrivateEndpointOutboundRuleDestination,
    PrivateLinkResource,
    PrivateLinkResourceListResult,
    PrivateLinkResourceProperties,
    PrivateLinkServiceConnectionState,
    Project,
    ProjectCapabilityHost,
    ProjectCapabilityHostProperties,
    ProjectProperties,
    ProvisioningIssue,
    ProvisioningIssueProperties,
    ProxyResource,
    QuotaLimit,
    QuotaTier,
    QuotaTierProperties,
    QuotaTierUpgradeEligibilityInfo,
    RaiBlocklist,
    RaiBlocklistConfig,
    RaiBlocklistItem,
    RaiBlocklistItemBulkRequest,
    RaiBlocklistItemProperties,
    RaiBlocklistProperties,
    RaiContentFilter,
    RaiContentFilterProperties,
    RaiEgressHeaderTransform,
    RaiEgressHeaderValueRef,
    RaiEgressManagedIdentityRef,
    RaiEgressPolicyConfig,
    RaiEgressRewriteTarget,
    RaiEgressRule,
    RaiEgressRuleAction,
    RaiEgressRuleMatch,
    RaiEgressSecretRef,
    RaiExternalSafetyProviderSchema,
    RaiExternalSafetyProviderSchemaProperties,
    RaiMonitorConfig,
    RaiPolicy,
    RaiPolicyContentFilter,
    RaiPolicyProperties,
    RaiSafetyProviderConfig,
    RaiToolLabel,
    RaiToolLabelProperties,
    RaiToolLabelPropertiesAccountScope,
    RaiToolLabelPropertiesProjectScopesItem,
    RaiTopic,
    RaiTopicProperties,
    RegenerateKeyParameters,
    RegionSetting,
    ReplacementConfig,
    RequestMatchPattern,
    Resource,
    ResourceBase,
    ResourceSku,
    ResourceSkuRestrictionInfo,
    ResourceSkuRestrictions,
    RoleBasedBuiltInAuthorizationPolicy,
    SASAuthTypeConnectionProperties,
    SafetyProviderConfig,
    ServicePrincipalAuthTypeConnectionProperties,
    ServiceTagOutboundRule,
    ServiceTagOutboundRuleDestination,
    Sku,
    SkuAvailability,
    SkuAvailabilityListResult,
    SkuCapability,
    SkuChangeInfo,
    SkuResource,
    SshSettings,
    SystemData,
    ThrottlingRule,
    TrafficRoutingRule,
    Usage,
    UsageListResult,
    UserAssignedIdentity,
    UserOwnedAmlWorkspace,
    UserOwnedStorage,
    UsernamePasswordAuthTypeConnectionProperties,
    VersionedAgentReference,
    VirtualNetworkRule,
    Workbench,
    WorkbenchProperties,
)

from ._enums import (  # type: ignore
    AbusePenaltyAction,
    ActionType,
    AgentDeploymentProvisioningState,
    AgentDeploymentState,
    AgentDeploymentType,
    AgentProtocol,
    AgenticApplicationProvisioningState,
    BuiltInAuthorizationScheme,
    ByPassSelection,
    CapabilityHostKind,
    CapabilityHostProvisioningState,
    CommitmentPlanProvisioningState,
    ComputeOperationStatusType,
    ComputeProvisioningState,
    ComputeType,
    ConnectionAuthType,
    ConnectionCategory,
    ConnectionGroup,
    ContentLevel,
    CreatedByType,
    DefenderForAISettingState,
    DeploymentModelVersionUpgradeOption,
    DeploymentProvisioningState,
    DeploymentScaleType,
    DeploymentState,
    DeprecationStatus,
    EncryptionScopeProvisioningState,
    EncryptionScopeState,
    FirewallSku,
    FoundryAutoUpgradeMode,
    HostingModel,
    IdentityKind,
    IdentityManagementType,
    IdentityProvisioningState,
    IsolationMode,
    KeyName,
    KeySource,
    ManagedNetworkKind,
    ManagedNetworkProvisioningState,
    ManagedNetworkStatus,
    ManagedPERequirement,
    ManagedPEStatus,
    ModelLifecycleStatus,
    NetworkRuleAction,
    NspAccessRuleDirection,
    Origin,
    PolicyEvaluationOutcome,
    PrivateEndpointConnectionProvisioningState,
    PrivateEndpointServiceConnectionStatus,
    ProvisioningState,
    PublicNetworkAccess,
    QuotaScopeType,
    QuotaUsageStatus,
    RaiActionType,
    RaiEgressDefaultAction,
    RaiEgressHeaderOperation,
    RaiEgressMode,
    RaiEgressRuleActionType,
    RaiEgressRuleType,
    RaiEgressScheme,
    RaiPolicyContentSource,
    RaiPolicyMode,
    RaiPolicyType,
    ResourceIdentityType,
    ResourceSkuRestrictionsReasonCode,
    ResourceSkuRestrictionsType,
    RoutingMethods,
    RoutingMode,
    RuleAction,
    RuleCategory,
    RuleStatus,
    RuleType,
    ScenarioType,
    ServiceTier,
    SkuTier,
    TierUpgradePolicy,
    TrafficRoutingProtocol,
    UnitType,
    UpgradeAvailabilityStatus,
    VmPriority,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AADAuthTypeConnectionProperties",
    "AbusePenalty",
    "AccessKeyAuthTypeConnectionProperties",
    "Account",
    "AccountKeyAuthTypeConnectionProperties",
    "AccountModel",
    "AccountProperties",
    "AccountSku",
    "AccountSkuListResult",
    "AgentApplication",
    "AgentDeployment",
    "AgentDeploymentProperties",
    "AgentProtocolVersion",
    "AgentReference",
    "AgentReferenceProperties",
    "AgentReferenceResourceArmPaginatedResult",
    "AgenticApplicationProperties",
    "ApiKeyAuthConnectionProperties",
    "ApiKeys",
    "ApiProperties",
    "ApplicationAuthorizationPolicy",
    "ApplicationTrafficRoutingPolicy",
    "AssignedIdentity",
    "BillingMeterInfo",
    "CalculateModelCapacityParameter",
    "CalculateModelCapacityResult",
    "CalculateModelCapacityResultEstimatedCapacity",
    "CallRateLimit",
    "CapabilityHost",
    "CapabilityHostProperties",
    "CapacityConfig",
    "ChannelsBuiltInAuthorizationPolicy",
    "CheckDomainAvailabilityParameter",
    "CheckSkuAvailabilityParameter",
    "ClusterComputeProperties",
    "CommitmentCost",
    "CommitmentPeriod",
    "CommitmentPlan",
    "CommitmentPlanAccountAssociation",
    "CommitmentPlanAccountAssociationProperties",
    "CommitmentPlanAssociation",
    "CommitmentPlanProperties",
    "CommitmentQuota",
    "CommitmentTier",
    "Compute",
    "ComputeOperationStatus",
    "ComputeOperationStatusProperties",
    "ComputeProperties",
    "ConnectionAccessKey",
    "ConnectionAccountKey",
    "ConnectionApiKey",
    "ConnectionManagedIdentity",
    "ConnectionOAuth2",
    "ConnectionPersonalAccessToken",
    "ConnectionPropertiesV2",
    "ConnectionPropertiesV2BasicResource",
    "ConnectionServicePrincipal",
    "ConnectionSharedAccessSignature",
    "ConnectionUpdateContent",
    "ConnectionUsernamePassword",
    "ConnectivityEndpoints",
    "ContainerInstanceComputeProperties",
    "CustomBlocklistConfig",
    "CustomKeys",
    "CustomKeysConnectionProperties",
    "DefenderForAISetting",
    "DefenderForAISettingProperties",
    "Deployment",
    "DeploymentCapacitySettings",
    "DeploymentModel",
    "DeploymentPolicyEvaluationResult",
    "DeploymentProperties",
    "DeploymentRouting",
    "DeploymentScaleSettings",
    "DeploymentSizeCapacity",
    "DeploymentSpeculativeDecoding",
    "DomainAvailability",
    "Encryption",
    "EncryptionScope",
    "EncryptionScopeProperties",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "EvaluateDeploymentPoliciesDeployment",
    "EvaluateDeploymentPoliciesDeploymentProperties",
    "EvaluateDeploymentPoliciesRequest",
    "EvaluateDeploymentPoliciesResponse",
    "FoundryAutoUpgrade",
    "FqdnOutboundRule",
    "HostedAgentDeployment",
    "Identity",
    "IpRule",
    "KeyVaultProperties",
    "ManagedAgentDeployment",
    "ManagedComputeCapacity",
    "ManagedComputeCapacityProperties",
    "ManagedComputeDeployment",
    "ManagedComputeDeploymentInfo",
    "ManagedComputeDeploymentProperties",
    "ManagedComputeDeploymentProvisioningDetails",
    "ManagedComputeDeploymentRoutes",
    "ManagedComputeUsage",
    "ManagedIdentityAuthTypeConnectionProperties",
    "ManagedNetworkProvisionOptions",
    "ManagedNetworkProvisionStatus",
    "ManagedNetworkSettings",
    "ManagedNetworkSettingsBasicResource",
    "ManagedNetworkSettingsEx",
    "ManagedNetworkSettingsProperties",
    "ManagedNetworkSettingsPropertiesBasicResource",
    "MetricName",
    "Model",
    "ModelCapacityCalculatorWorkload",
    "ModelCapacityCalculatorWorkloadRequestParam",
    "ModelCapacityListResultValueItem",
    "ModelDeprecationInfo",
    "ModelSku",
    "ModelSkuCapacityProperties",
    "MultiRegionSettings",
    "NetworkInjection",
    "NetworkRuleSet",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterAccessRule",
    "NetworkSecurityPerimeterAccessRuleProperties",
    "NetworkSecurityPerimeterAccessRulePropertiesSubscriptionsItem",
    "NetworkSecurityPerimeterConfiguration",
    "NetworkSecurityPerimeterConfigurationAssociationInfo",
    "NetworkSecurityPerimeterConfigurationProperties",
    "NetworkSecurityPerimeterProfileInfo",
    "NoneAuthTypeConnectionProperties",
    "OAuth2AuthTypeConnectionProperties",
    "Operation",
    "OperationDisplay",
    "OrganizationSharedBuiltInAuthorizationPolicy",
    "OutboundRule",
    "OutboundRuleBasicResource",
    "PATAuthTypeConnectionProperties",
    "PatchResourceSku",
    "PatchResourceTags",
    "PatchResourceTagsAndSku",
    "PolicyAssignmentEvaluationDetails",
    "PolicyExpressionEvaluationDetails",
    "Pool",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionListResult",
    "PrivateEndpointConnectionProperties",
    "PrivateEndpointOutboundRule",
    "PrivateEndpointOutboundRuleDestination",
    "PrivateLinkResource",
    "PrivateLinkResourceListResult",
    "PrivateLinkResourceProperties",
    "PrivateLinkServiceConnectionState",
    "Project",
    "ProjectCapabilityHost",
    "ProjectCapabilityHostProperties",
    "ProjectProperties",
    "ProvisioningIssue",
    "ProvisioningIssueProperties",
    "ProxyResource",
    "QuotaLimit",
    "QuotaTier",
    "QuotaTierProperties",
    "QuotaTierUpgradeEligibilityInfo",
    "RaiBlocklist",
    "RaiBlocklistConfig",
    "RaiBlocklistItem",
    "RaiBlocklistItemBulkRequest",
    "RaiBlocklistItemProperties",
    "RaiBlocklistProperties",
    "RaiContentFilter",
    "RaiContentFilterProperties",
    "RaiEgressHeaderTransform",
    "RaiEgressHeaderValueRef",
    "RaiEgressManagedIdentityRef",
    "RaiEgressPolicyConfig",
    "RaiEgressRewriteTarget",
    "RaiEgressRule",
    "RaiEgressRuleAction",
    "RaiEgressRuleMatch",
    "RaiEgressSecretRef",
    "RaiExternalSafetyProviderSchema",
    "RaiExternalSafetyProviderSchemaProperties",
    "RaiMonitorConfig",
    "RaiPolicy",
    "RaiPolicyContentFilter",
    "RaiPolicyProperties",
    "RaiSafetyProviderConfig",
    "RaiToolLabel",
    "RaiToolLabelProperties",
    "RaiToolLabelPropertiesAccountScope",
    "RaiToolLabelPropertiesProjectScopesItem",
    "RaiTopic",
    "RaiTopicProperties",
    "RegenerateKeyParameters",
    "RegionSetting",
    "ReplacementConfig",
    "RequestMatchPattern",
    "Resource",
    "ResourceBase",
    "ResourceSku",
    "ResourceSkuRestrictionInfo",
    "ResourceSkuRestrictions",
    "RoleBasedBuiltInAuthorizationPolicy",
    "SASAuthTypeConnectionProperties",
    "SafetyProviderConfig",
    "ServicePrincipalAuthTypeConnectionProperties",
    "ServiceTagOutboundRule",
    "ServiceTagOutboundRuleDestination",
    "Sku",
    "SkuAvailability",
    "SkuAvailabilityListResult",
    "SkuCapability",
    "SkuChangeInfo",
    "SkuResource",
    "SshSettings",
    "SystemData",
    "ThrottlingRule",
    "TrafficRoutingRule",
    "Usage",
    "UsageListResult",
    "UserAssignedIdentity",
    "UserOwnedAmlWorkspace",
    "UserOwnedStorage",
    "UsernamePasswordAuthTypeConnectionProperties",
    "VersionedAgentReference",
    "VirtualNetworkRule",
    "Workbench",
    "WorkbenchProperties",
    "AbusePenaltyAction",
    "ActionType",
    "AgentDeploymentProvisioningState",
    "AgentDeploymentState",
    "AgentDeploymentType",
    "AgentProtocol",
    "AgenticApplicationProvisioningState",
    "BuiltInAuthorizationScheme",
    "ByPassSelection",
    "CapabilityHostKind",
    "CapabilityHostProvisioningState",
    "CommitmentPlanProvisioningState",
    "ComputeOperationStatusType",
    "ComputeProvisioningState",
    "ComputeType",
    "ConnectionAuthType",
    "ConnectionCategory",
    "ConnectionGroup",
    "ContentLevel",
    "CreatedByType",
    "DefenderForAISettingState",
    "DeploymentModelVersionUpgradeOption",
    "DeploymentProvisioningState",
    "DeploymentScaleType",
    "DeploymentState",
    "DeprecationStatus",
    "EncryptionScopeProvisioningState",
    "EncryptionScopeState",
    "FirewallSku",
    "FoundryAutoUpgradeMode",
    "HostingModel",
    "IdentityKind",
    "IdentityManagementType",
    "IdentityProvisioningState",
    "IsolationMode",
    "KeyName",
    "KeySource",
    "ManagedNetworkKind",
    "ManagedNetworkProvisioningState",
    "ManagedNetworkStatus",
    "ManagedPERequirement",
    "ManagedPEStatus",
    "ModelLifecycleStatus",
    "NetworkRuleAction",
    "NspAccessRuleDirection",
    "Origin",
    "PolicyEvaluationOutcome",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "ProvisioningState",
    "PublicNetworkAccess",
    "QuotaScopeType",
    "QuotaUsageStatus",
    "RaiActionType",
    "RaiEgressDefaultAction",
    "RaiEgressHeaderOperation",
    "RaiEgressMode",
    "RaiEgressRuleActionType",
    "RaiEgressRuleType",
    "RaiEgressScheme",
    "RaiPolicyContentSource",
    "RaiPolicyMode",
    "RaiPolicyType",
    "ResourceIdentityType",
    "ResourceSkuRestrictionsReasonCode",
    "ResourceSkuRestrictionsType",
    "RoutingMethods",
    "RoutingMode",
    "RuleAction",
    "RuleCategory",
    "RuleStatus",
    "RuleType",
    "ScenarioType",
    "ServiceTier",
    "SkuTier",
    "TierUpgradePolicy",
    "TrafficRoutingProtocol",
    "UnitType",
    "UpgradeAvailabilityStatus",
    "VmPriority",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AbusePenaltyAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action of AbusePenalty."""

    THROTTLE = "Throttle"
    """THROTTLE."""
    BLOCK = "Block"
    """BLOCK."""


class ActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Extensible enum. Indicates the action type. "Internal" refers to actions that are for internal
    only APIs.
    """

    INTERNAL = "Internal"
    """Actions are for internal-only APIs."""


class AgentDeploymentProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of an agentic deployment, as an Azure resource."""

    SUCCEEDED = "Succeeded"
    """The deployment was successfully completed."""
    FAILED = "Failed"
    """The deployment failed."""
    CANCELED = "Canceled"
    """The deployment was canceled."""
    CREATING = "Creating"
    """The deployment is being created."""
    UPDATING = "Updating"
    """The deployment is being updated."""
    DELETING = "Deleting"
    """The deployment is being deleted."""


class AgentDeploymentState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current operational state of the agentic functionality represented by this deployment."""

    STARTING = "Starting"
    """The deployment is starting."""
    RUNNING = "Running"
    """The deployment started/is operational."""
    STOPPING = "Stopping"
    """The deployment is being stopped."""
    STOPPED = "Stopped"
    """The deployment was stopped."""
    FAILED = "Failed"
    """The deployment failed."""
    DELETING = "Deleting"
    """The deployment is being deleted."""
    DELETED = "Deleted"
    """The deployment was deleted."""
    UPDATING = "Updating"
    """The deployment is being updated."""


class AgentDeploymentType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the type of deployment for an agent, indicating how the underlying compute and
    network infrastructure is managed.
    """

    MANAGED = "Managed"
    """The underlying infra is managed by the platform in the deployer's subscription."""
    HOSTED = "Hosted"
    """The underlying infra is owned by the platform."""
    CUSTOM = "Custom"
    """The underlying infra is provisioned by the deployer (BYO)."""


class AgenticApplicationProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of an agentic application."""

    SUCCEEDED = "Succeeded"
    """The application was successfully provisioned."""
    FAILED = "Failed"
    """The application provisioning failed."""
    CANCELED = "Canceled"
    """The application provisioning was canceled."""
    CREATING = "Creating"
    """The application is being created."""
    UPDATING = "Updating"
    """The application is being updated."""
    DELETING = "Deleting"
    """The application is being deleted."""


class AgentProtocol(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Protocol used by the agent/exposed by a deployment."""

    AGENT = "Agent"
    """Agent protocol (aka Active)."""
    A2_A = "A2A"
    """Agent2Agent standard."""
    RESPONSES = "Responses"
    """OpenAI-compatible."""


class BuiltInAuthorizationScheme(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Authorization scheme type."""

    DEFAULT = "Default"
    """Standard AzureML RBAC."""
    ORGANIZATION_SCOPE = "OrganizationScope"
    """Claim-based, requires membership in the tenant."""
    CHANNELS = "Channels"
    """Channels-specific (AzureBotService) authorization."""
    CUSTOM = "Custom"
    """Custom scheme defined by the application author."""


class ByPassSelection(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Setting for trusted services."""

    NONE = "None"
    """NONE."""
    AZURE_SERVICES = "AzureServices"
    """AZURE_SERVICES."""


class CapabilityHostKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of CapabilityHostKind."""

    AGENTS = "Agents"
    """AGENTS."""


class CapabilityHostProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of capability host."""

    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    FAILED = "Failed"
    """FAILED."""
    CANCELED = "Canceled"
    """CANCELED."""
    CREATING = "Creating"
    """CREATING."""
    UPDATING = "Updating"
    """UPDATING."""
    DELETING = "Deleting"
    """DELETING."""


class CommitmentPlanProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets the status of the resource at the time the operation was called."""

    ACCEPTED = "Accepted"
    """ACCEPTED."""
    CREATING = "Creating"
    """CREATING."""
    DELETING = "Deleting"
    """DELETING."""
    MOVING = "Moving"
    """MOVING."""
    FAILED = "Failed"
    """FAILED."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    CANCELED = "Canceled"
    """CANCELED."""


class ComputeOperationStatusType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The status type of a compute operation."""

    IN_PROGRESS = "InProgress"
    """The operation is in progress."""
    SUCCEEDED = "Succeeded"
    """The operation has succeeded."""
    FAILED = "Failed"
    """The operation has failed."""
    CANCELED = "Canceled"
    """The operation has been canceled."""


class ComputeProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The provisioning state of a compute resource."""

    ACCEPTED = "Accepted"
    """The resource provisioning request has been accepted."""
    SUCCEEDED = "Succeeded"
    """The resource has been fully provisioned."""
    FAILED = "Failed"
    """The resource provisioning has failed."""
    CANCELED = "Canceled"
    """The resource provisioning was canceled."""
    DELETING = "Deleting"
    """The resource is being deleted."""
    SCALING = "Scaling"
    """The resource is scaling."""
    DISABLED = "Disabled"
    """The resource is disabled."""
    STARTING = "Starting"
    """The compute resource is starting."""
    STOPPING = "Stopping"
    """The compute resource is stopping."""
    RESTARTING = "Restarting"
    """The compute resource is restarting."""
    STOPPED = "Stopped"
    """The compute resource is stopped."""


class ComputeType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of compute resource."""

    CLUSTER = "Cluster"
    """Cluster (AKS-backed) compute type."""
    CONTAINER_INSTANCE = "ContainerInstance"
    """Container Instance compute type."""


class ConnectionAuthType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Authentication type of the connection target."""

    PAT = "PAT"
    """PAT."""
    MANAGED_IDENTITY = "ManagedIdentity"
    """MANAGED_IDENTITY."""
    USERNAME_PASSWORD = "UsernamePassword"
    """USERNAME_PASSWORD."""
    NONE = "None"
    """NONE."""
    SAS = "SAS"
    """SAS."""
    ACCOUNT_KEY = "AccountKey"
    """ACCOUNT_KEY."""
    SERVICE_PRINCIPAL = "ServicePrincipal"
    """SERVICE_PRINCIPAL."""
    ACCESS_KEY = "AccessKey"
    """ACCESS_KEY."""
    API_KEY = "ApiKey"
    """API_KEY."""
    CUSTOM_KEYS = "CustomKeys"
    """CUSTOM_KEYS."""
    O_AUTH2 = "OAuth2"
    """O_AUTH2."""
    AAD = "AAD"
    """AAD."""
    DELEGATED_SAS = "DelegatedSAS"
    """DELEGATED_SAS."""
    PROJECT_MANAGED_IDENTITY = "ProjectManagedIdentity"
    """PROJECT_MANAGED_IDENTITY."""
    ACCOUNT_MANAGED_IDENTITY = "AccountManagedIdentity"
    """ACCOUNT_MANAGED_IDENTITY."""
    USER_ENTRA_TOKEN = "UserEntraToken"
    """USER_ENTRA_TOKEN."""
    AGENT_USER_IMPERSONATION = "AgentUserImpersonation"
    """AGENT_USER_IMPERSONATION."""
    AGENTIC_IDENTITY_TOKEN = "AgenticIdentityToken"
    """AGENTIC_IDENTITY_TOKEN."""
    AGENTIC_USER = "AgenticUser"
    """AGENTIC_USER."""


class ConnectionCategory(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Category of the connection."""

    PYTHON_FEED = "PythonFeed"
    """PYTHON_FEED."""
    CONTAINER_REGISTRY = "ContainerRegistry"
    """CONTAINER_REGISTRY."""
    GIT = "Git"
    """GIT."""
    S3 = "S3"
    """S3."""
    SNOWFLAKE = "Snowflake"
    """SNOWFLAKE."""
    AZURE_KEY_VAULT = "AzureKeyVault"
    """AZURE_KEY_VAULT."""
    AZURE_SQL_DB = "AzureSqlDb"
    """AZURE_SQL_DB."""
    AZURE_SYNAPSE_ANALYTICS = "AzureSynapseAnalytics"
    """AZURE_SYNAPSE_ANALYTICS."""
    AZURE_MY_SQL_DB = "AzureMySqlDb"
    """AZURE_MY_SQL_DB."""
    AZURE_POSTGRES_DB = "AzurePostgresDb"
    """AZURE_POSTGRES_DB."""
    ADLS_GEN2 = "ADLSGen2"
    """ADLS_GEN2."""
    AZURE_CONTAINER_APP_ENVIRONMENT = "AzureContainerAppEnvironment"
    """AZURE_CONTAINER_APP_ENVIRONMENT."""
    REDIS = "Redis"
    """REDIS."""
    API_KEY = "ApiKey"
    """API_KEY."""
    AZURE_OPEN_AI = "AzureOpenAI"
    """AZURE_OPEN_AI."""
    AI_SERVICES = "AIServices"
    """AI_SERVICES."""
    COGNITIVE_SEARCH = "CognitiveSearch"
    """COGNITIVE_SEARCH."""
    COGNITIVE_SERVICE = "CognitiveService"
    """COGNITIVE_SERVICE."""
    CUSTOM_KEYS = "CustomKeys"
    """CUSTOM_KEYS."""
    AZURE_BLOB = "AzureBlob"
    """AZURE_BLOB."""
    AZURE_STORAGE_ACCOUNT = "AzureStorageAccount"
    """AZURE_STORAGE_ACCOUNT."""
    AZURE_ONE_LAKE = "AzureOneLake"
    """AZURE_ONE_LAKE."""
    COSMOS_DB = "CosmosDb"
    """COSMOS_DB."""
    COSMOS_DB_MONGO_DB_API = "CosmosDbMongoDbApi"
    """COSMOS_DB_MONGO_DB_API."""
    AZURE_DATA_EXPLORER = "AzureDataExplorer"
    """AZURE_DATA_EXPLORER."""
    AZURE_MARIA_DB = "AzureMariaDb"
    """AZURE_MARIA_DB."""
    AZURE_DATABRICKS_DELTA_LAKE = "AzureDatabricksDeltaLake"
    """AZURE_DATABRICKS_DELTA_LAKE."""
    AZURE_SQL_MI = "AzureSqlMi"
    """AZURE_SQL_MI."""
    AZURE_TABLE_STORAGE = "AzureTableStorage"
    """AZURE_TABLE_STORAGE."""
    AMAZON_RDS_FOR_ORACLE = "AmazonRdsForOracle"
    """AMAZON_RDS_FOR_ORACLE."""
    AMAZON_RDS_FOR_SQL_SERVER = "AmazonRdsForSqlServer"
    """AMAZON_RDS_FOR_SQL_SERVER."""
    AMAZON_REDSHIFT = "AmazonRedshift"
    """AMAZON_REDSHIFT."""
    DB2 = "Db2"
    """DB2."""
    DRILL = "Drill"
    """DRILL."""
    GOOGLE_BIG_QUERY = "GoogleBigQuery"
    """GOOGLE_BIG_QUERY."""
    GREENPLUM = "Greenplum"
    """GREENPLUM."""
    HBASE = "Hbase"
    """HBASE."""
    HIVE = "Hive"
    """HIVE."""
    IMPALA = "Impala"
    """IMPALA."""
    INFORMIX = "Informix"
    """INFORMIX."""
    MARIA_DB = "MariaDb"
    """MARIA_DB."""
    MICROSOFT_ACCESS = "MicrosoftAccess"
    """MICROSOFT_ACCESS."""
    MY_SQL = "MySql"
    """MY_SQL."""
    NETEZZA = "Netezza"
    """NETEZZA."""
    ORACLE = "Oracle"
    """ORACLE."""
    PHOENIX = "Phoenix"
    """PHOENIX."""
    POSTGRE_SQL = "PostgreSql"
    """POSTGRE_SQL."""
    PRESTO = "Presto"
    """PRESTO."""
    SAP_OPEN_HUB = "SapOpenHub"
    """SAP_OPEN_HUB."""
    SAP_BW = "SapBw"
    """SAP_BW."""
    SAP_HANA = "SapHana"
    """SAP_HANA."""
    SAP_TABLE = "SapTable"
    """SAP_TABLE."""
    SPARK = "Spark"
    """SPARK."""
    SQL_SERVER = "SqlServer"
    """SQL_SERVER."""
    SYBASE = "Sybase"
    """SYBASE."""
    TERADATA = "Teradata"
    """TERADATA."""
    VERTICA = "Vertica"
    """VERTICA."""
    PINECONE = "Pinecone"
    """PINECONE."""
    DATABRICKS = "Databricks"
    """DATABRICKS."""
    CASSANDRA = "Cassandra"
    """CASSANDRA."""
    COUCHBASE = "Couchbase"
    """COUCHBASE."""
    MONGO_DB_V2 = "MongoDbV2"
    """MONGO_DB_V2."""
    MONGO_DB_ATLAS = "MongoDbAtlas"
    """MONGO_DB_ATLAS."""
    AMAZON_S3_COMPATIBLE = "AmazonS3Compatible"
    """AMAZON_S3_COMPATIBLE."""
    FILE_SERVER = "FileServer"
    """FILE_SERVER."""
    FTP_SERVER = "FtpServer"
    """FTP_SERVER."""
    GOOGLE_CLOUD_STORAGE = "GoogleCloudStorage"
    """GOOGLE_CLOUD_STORAGE."""
    HDFS = "Hdfs"
    """HDFS."""
    ORACLE_CLOUD_STORAGE = "OracleCloudStorage"
    """ORACLE_CLOUD_STORAGE."""
    SFTP = "Sftp"
    """SFTP."""
    GENERIC_HTTP = "GenericHttp"
    """GENERIC_HTTP."""
    O_DATA_REST = "ODataRest"
    """O_DATA_REST."""
    ODBC = "Odbc"
    """ODBC."""
    GENERIC_REST = "GenericRest"
    """GENERIC_REST."""
    REMOTE_TOOL = "RemoteTool"
    """REMOTE_TOOL."""
    AMAZON_MWS = "AmazonMws"
    """AMAZON_MWS."""
    CONCUR = "Concur"
    """CONCUR."""
    DYNAMICS = "Dynamics"
    """DYNAMICS."""
    DYNAMICS_AX = "DynamicsAx"
    """DYNAMICS_AX."""
    DYNAMICS_CRM = "DynamicsCrm"
    """DYNAMICS_CRM."""
    GOOGLE_AD_WORDS = "GoogleAdWords"
    """GOOGLE_AD_WORDS."""
    HUBSPOT = "Hubspot"
    """HUBSPOT."""
    JIRA = "Jira"
    """JIRA."""
    MAGENTO = "Magento"
    """MAGENTO."""
    MARKETO = "Marketo"
    """MARKETO."""
    OFFICE365 = "Office365"
    """OFFICE365."""
    ELOQUA = "Eloqua"
    """ELOQUA."""
    RESPONSYS = "Responsys"
    """RESPONSYS."""
    ORACLE_SERVICE_CLOUD = "OracleServiceCloud"
    """ORACLE_SERVICE_CLOUD."""
    PAY_PAL = "PayPal"
    """PAY_PAL."""
    QUICK_BOOKS = "QuickBooks"
    """QUICK_BOOKS."""
    SALESFORCE = "Salesforce"
    """SALESFORCE."""
    SALESFORCE_SERVICE_CLOUD = "SalesforceServiceCloud"
    """SALESFORCE_SERVICE_CLOUD."""
    SALESFORCE_MARKETING_CLOUD = "SalesforceMarketingCloud"
    """SALESFORCE_MARKETING_CLOUD."""
    SAP_CLOUD_FOR_CUSTOMER = "SapCloudForCustomer"
    """SAP_CLOUD_FOR_CUSTOMER."""
    SAP_ECC = "SapEcc"
    """SAP_ECC."""
    SERVICE_NOW = "ServiceNow"
    """SERVICE_NOW."""
    SHARE_POINT_ONLINE_LIST = "SharePointOnlineList"
    """SHARE_POINT_ONLINE_LIST."""
    SHOPIFY = "Shopify"
    """SHOPIFY."""
    SQUARE = "Square"
    """SQUARE."""
    WEB_TABLE = "WebTable"
    """WEB_TABLE."""
    XERO = "Xero"
    """XERO."""
    ZOHO = "Zoho"
    """ZOHO."""
    GENERIC_CONTAINER_REGISTRY = "GenericContainerRegistry"
    """GENERIC_CONTAINER_REGISTRY."""
    ELASTICSEARCH = "Elasticsearch"
    """ELASTICSEARCH."""
    APP_INSIGHTS = "AppInsights"
    """APP_INSIGHTS."""
    APP_CONFIG = "AppConfig"
    """APP_CONFIG."""
    OPEN_AI = "OpenAI"
    """OPEN_AI."""
    SERP = "Serp"
    """SERP."""
    BING_LLM_SEARCH = "BingLLMSearch"
    """BING_LLM_SEARCH."""
    SERVERLESS = "Serverless"
    """SERVERLESS."""
    MANAGED_ONLINE_ENDPOINT = "ManagedOnlineEndpoint"
    """MANAGED_ONLINE_ENDPOINT."""
    API_MANAGEMENT = "ApiManagement"
    """API_MANAGEMENT."""
    MODEL_GATEWAY = "ModelGateway"
    """MODEL_GATEWAY."""
    GROUNDING_WITH_BING_SEARCH = "GroundingWithBingSearch"
    """GROUNDING_WITH_BING_SEARCH."""
    GROUNDING_WITH_CUSTOM_SEARCH = "GroundingWithCustomSearch"
    """GROUNDING_WITH_CUSTOM_SEARCH."""
    SHAREPOINT = "Sharepoint"
    """SHAREPOINT."""
    MICROSOFT_FABRIC = "MicrosoftFabric"
    """MICROSOFT_FABRIC."""
    POWER_PLATFORM_ENVIRONMENT = "PowerPlatformEnvironment"
    """POWER_PLATFORM_ENVIRONMENT."""
    REMOTE_A2_A = "RemoteA2A"
    """REMOTE_A2_A."""


class ConnectionGroup(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Group based on connection category."""

    AZURE = "Azure"
    """AZURE."""
    AZURE_AI = "AzureAI"
    """AZURE_AI."""
    DATABASE = "Database"
    """DATABASE."""
    NO_SQL = "NoSQL"
    """NO_SQL."""
    FILE = "File"
    """FILE."""
    GENERIC_PROTOCOL = "GenericProtocol"
    """GENERIC_PROTOCOL."""
    SERVICES_AND_APPS = "ServicesAndApps"
    """SERVICES_AND_APPS."""


class ContentLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Level at which content is filtered."""

    LOW = "Low"
    """LOW."""
    MEDIUM = "Medium"
    """MEDIUM."""
    HIGH = "High"
    """HIGH."""


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of entity that created the resource."""

    USER = "User"
    """The entity was created by a user."""
    APPLICATION = "Application"
    """The entity was created by an application."""
    MANAGED_IDENTITY = "ManagedIdentity"
    """The entity was created by a managed identity."""
    KEY = "Key"
    """The entity was created by a key."""


class DefenderForAISettingState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Defender for AI state on the AI resource."""

    DISABLED = "Disabled"
    """DISABLED."""
    ENABLED = "Enabled"
    """ENABLED."""


class DeploymentModelVersionUpgradeOption(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Deployment model version upgrade option."""

    ONCE_NEW_DEFAULT_VERSION_AVAILABLE = "OnceNewDefaultVersionAvailable"
    """ONCE_NEW_DEFAULT_VERSION_AVAILABLE."""
    ONCE_CURRENT_VERSION_EXPIRED = "OnceCurrentVersionExpired"
    """ONCE_CURRENT_VERSION_EXPIRED."""
    NO_AUTO_UPGRADE = "NoAutoUpgrade"
    """NO_AUTO_UPGRADE."""


class DeploymentProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets the status of the resource at the time the operation was called."""

    ACCEPTED = "Accepted"
    """ACCEPTED."""
    CREATING = "Creating"
    """CREATING."""
    DELETING = "Deleting"
    """DELETING."""
    MOVING = "Moving"
    """MOVING."""
    FAILED = "Failed"
    """FAILED."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    DISABLED = "Disabled"
    """DISABLED."""
    CANCELED = "Canceled"
    """CANCELED."""


class DeploymentScaleType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Deployment scale type."""

    STANDARD = "Standard"
    """STANDARD."""
    MANUAL = "Manual"
    """MANUAL."""


class DeploymentState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The state of the deployment. Controls whether the deployment is accepting inference requests.
    Use 'Running' for active deployments that process requests, or 'Paused' to temporarily stop
    inference while preserving the deployment configuration.
    """

    RUNNING = "Running"
    """The deployment is running and accepting inference requests."""
    PAUSED = "Paused"
    """The deployment is paused and not accepting inference requests."""


class DeprecationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Indicates whether the deprecation date is a confirmed planned end-of-life date or an estimated
    deprecation date. When 'Planned', the deprecation date represents a confirmed and communicated
    model end-of-life date. When 'Tentative', the deprecation date is an estimated timeline that
    may be subject to change.
    """

    PLANNED = "Planned"
    """PLANNED."""
    TENTATIVE = "Tentative"
    """TENTATIVE."""


class EncryptionScopeProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets the status of the resource at the time the operation was called."""

    ACCEPTED = "Accepted"
    """ACCEPTED."""
    CREATING = "Creating"
    """CREATING."""
    DELETING = "Deleting"
    """DELETING."""
    MOVING = "Moving"
    """MOVING."""
    FAILED = "Failed"
    """FAILED."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    CANCELED = "Canceled"
    """CANCELED."""


class EncryptionScopeState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The encryptionScope state."""

    DISABLED = "Disabled"
    """DISABLED."""
    ENABLED = "Enabled"
    """ENABLED."""


class FirewallSku(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Firewall Sku used for FQDN Rules."""

    STANDARD = "Standard"
    """STANDARD."""
    BASIC = "Basic"
    """BASIC."""


class FoundryAutoUpgradeMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Represents the mode for foundry auto-upgrade configuration."""

    ENABLED = "Enabled"
    """Auto-upgrade is enabled."""
    DISABLED = "Disabled"
    """Auto-upgrade is disabled (opted out)."""


class HostingModel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Account hosting model."""

    WEB = "Web"
    """WEB."""
    CONNECTED_CONTAINER = "ConnectedContainer"
    """CONNECTED_CONTAINER."""
    DISCONNECTED_CONTAINER = "DisconnectedContainer"
    """DISCONNECTED_CONTAINER."""
    PROVISIONED_WEB = "ProvisionedWeb"
    """PROVISIONED_WEB."""


class IdentityKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the kind of Entra identity described by this object."""

    AGENT_BLUEPRINT = "AgentBlueprint"
    """Represents a class identity, used for agentic applications."""
    AGENT_INSTANCE = "AgentInstance"
    """Represents an instance identity."""
    AGENTIC_USER = "AgenticUser"
    """Represents an agentic instance identity with user-like traits."""
    MANAGED = "Managed"
    """Represents a classic managed identity."""
    NONE = "None"
    """No identity."""


class IdentityManagementType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enumeration of identity types, from the perspective of management."""

    SYSTEM = "System"
    """Platform-managed identity."""
    USER = "User"
    """User-managed identity."""
    NONE = "None"
    """No identity."""


class IdentityProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Represents the provisioning state of an identity resource."""

    CREATING = "Creating"
    """Identity is being created."""
    UPDATING = "Updating"
    """Identity is being updated."""
    SUCCEEDED = "Succeeded"
    """Identity has been successfully provisioned."""
    FAILED = "Failed"
    """Identity provisioning has failed."""
    CANCELED = "Canceled"
    """Identity provisioning has been canceled."""
    DELETING = "Deleting"
    """Identity is being deleted."""


class IsolationMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Isolation mode for the managed network of a cognitive services account."""

    DISABLED = "Disabled"
    """DISABLED."""
    ALLOW_INTERNET_OUTBOUND = "AllowInternetOutbound"
    """ALLOW_INTERNET_OUTBOUND."""
    ALLOW_ONLY_APPROVED_OUTBOUND = "AllowOnlyApprovedOutbound"
    """ALLOW_ONLY_APPROVED_OUTBOUND."""


class KeyName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """key name to generate (Key1|Key2)."""

    KEY1 = "Key1"
    """KEY1."""
    KEY2 = "Key2"
    """KEY2."""


class KeySource(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enumerates the possible value of keySource for Encryption."""

    MICROSOFT_COGNITIVE_SERVICES = "Microsoft.CognitiveServices"
    """MICROSOFT_COGNITIVE_SERVICES."""
    MICROSOFT_KEY_VAULT = "Microsoft.KeyVault"
    """MICROSOFT_KEY_VAULT."""


class ManagedNetworkKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The Kind of the managed network. Users can switch from V1 to V2 for granular access controls,
    but cannot switch back to V1 once V2 is enabled.
    """

    V1 = "V1"
    """V1."""
    V2 = "V2"
    """V2."""


class ManagedNetworkProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of ManagedNetworkProvisioningState."""

    DEFERRED = "Deferred"
    """DEFERRED."""
    UPDATING = "Updating"
    """UPDATING."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    FAILED = "Failed"
    """FAILED."""
    DELETING = "Deleting"
    """DELETING."""
    DELETED = "Deleted"
    """DELETED."""


class ManagedNetworkStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status for the managed network of a cognitive services account."""

    INACTIVE = "Inactive"
    """INACTIVE."""
    ACTIVE = "Active"
    """ACTIVE."""


class ManagedPERequirement(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of ManagedPERequirement."""

    REQUIRED = "Required"
    """REQUIRED."""
    NOT_REQUIRED = "NotRequired"
    """NOT_REQUIRED."""
    NOT_APPLICABLE = "NotApplicable"
    """NOT_APPLICABLE."""


class ManagedPEStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of ManagedPEStatus."""

    INACTIVE = "Inactive"
    """INACTIVE."""
    ACTIVE = "Active"
    """ACTIVE."""
    NOT_APPLICABLE = "NotApplicable"
    """NOT_APPLICABLE."""


class ModelLifecycleStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Model lifecycle status."""

    STABLE = "Stable"
    """Legacy state. Replaced with GenerallyAvailable going forward."""
    PREVIEW = "Preview"
    """Model is in preview and may be subject to changes."""
    GENERALLY_AVAILABLE = "GenerallyAvailable"
    """Model is generally available for production use."""
    DEPRECATING = "Deprecating"
    """Model is being deprecated and will be removed in the future. Only customers with existing
    deployments can create new deployments with this model."""
    DEPRECATED = "Deprecated"
    """Model has been deprecated, also known as retired, and is no longer supported. Inference calls
    to deployments of models in this lifecycle state will return 410 errors."""
    LEGACY = "Legacy"
    """Model is a legacy version that is no longer recommended for use. Customers should migrate to
    newer models. Check replacementConfig for upgrade information."""


class NetworkRuleAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The default action when no rule from ipRules and from virtualNetworkRules match. This is only
    used after the bypass property has been evaluated.
    """

    ALLOW = "Allow"
    """ALLOW."""
    DENY = "Deny"
    """DENY."""


class NspAccessRuleDirection(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Direction of Access Rule."""

    INBOUND = "Inbound"
    """INBOUND."""
    OUTBOUND = "Outbound"
    """OUTBOUND."""


class Origin(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The intended executor of the operation; as in Resource Based Access Control (RBAC) and audit
    logs UX. Default value is "user,system".
    """

    USER = "user"
    """Indicates the operation is initiated by a user."""
    SYSTEM = "system"
    """Indicates the operation is initiated by a system."""
    USER_SYSTEM = "user,system"
    """Indicates the operation is initiated by a user or system."""


class PolicyEvaluationOutcome(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The outcome of a policy evaluation."""

    COMPLIANT = "Compliant"
    """The deployment is compliant with all policies."""
    NON_COMPLIANT = "NonCompliant"
    """The deployment violates one or more policies."""
    ERROR = "Error"
    """An error occurred during evaluation."""


class PrivateEndpointConnectionProvisioningState(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """The current provisioning state."""

    SUCCEEDED = "Succeeded"
    """Connection has been provisioned."""
    CREATING = "Creating"
    """Connection is being created."""
    DELETING = "Deleting"
    """Connection is being deleted."""
    FAILED = "Failed"
    """Connection provisioning has failed."""


class PrivateEndpointServiceConnectionStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The private endpoint connection status."""

    PENDING = "Pending"
    """Connection waiting for approval or rejection."""
    APPROVED = "Approved"
    """Connection approved."""
    REJECTED = "Rejected"
    """Connection Rejected."""


class ProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets the status of the cognitive services account at the time the operation was called."""

    ACCEPTED = "Accepted"
    """ACCEPTED."""
    CREATING = "Creating"
    """CREATING."""
    DELETING = "Deleting"
    """DELETING."""
    MOVING = "Moving"
    """MOVING."""
    FAILED = "Failed"
    """FAILED."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    CANCELED = "Canceled"
    """CANCELED."""
    RESOLVING_DNS = "ResolvingDNS"
    """RESOLVING_DNS."""


class PublicNetworkAccess(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Whether or not public endpoint access is allowed for this account."""

    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""


class QuotaScopeType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The quota scope that determines the level at which the quota is applied."""

    REGIONAL = "Regional"
    """REGIONAL."""
    GLOBAL = "Global"
    """GLOBAL."""
    DATA_ZONE = "DataZone"
    """DATA_ZONE."""
    CLASSIC = "Classic"
    """CLASSIC."""


class QuotaUsageStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Cognitive Services account quota usage status."""

    INCLUDED = "Included"
    """INCLUDED."""
    BLOCKED = "Blocked"
    """BLOCKED."""
    IN_OVERAGE = "InOverage"
    """IN_OVERAGE."""
    UNKNOWN = "Unknown"
    """UNKNOWN."""


class RaiActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action types to apply to the content filters."""

    NONE = "None"
    """NONE."""
    BLOCKING = "BLOCKING"
    """BLOCKING."""
    ANNOTATING = "ANNOTATING"
    """ANNOTATING."""
    HITL = "HITL"
    """HITL."""
    RETRY = "RETRY"
    """RETRY."""


class RaiEgressDefaultAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The default action when no user-defined egress rules match."""

    ALLOW = "Allow"
    """Allow traffic by default when no rules match."""
    DENY = "Deny"
    """Deny traffic by default when no rules match."""


class RaiEgressHeaderOperation(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The operation to apply to a header in a Transform or Rewrite action."""

    SET = "Set"
    """Set or overwrite the header value, creating it if it does not exist."""
    INSERT = "Insert"
    """Add the header only if it is not already present."""
    REMOVE = "Remove"
    """Remove the header if present."""


class RaiEgressMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The enforcement mode for egress rules. If omitted on create, the server defaults to Enforced."""

    ENFORCED = "Enforced"
    """Rules are enforced. Matching traffic is allowed or denied per rule actions."""
    AUDIT = "Audit"
    """Rules are evaluated and logged but not enforced. Traffic is always forwarded regardless of rule
    action. A would-be Deny is logged but not applied. Transform and Rewrite actions are still
    applied to matching traffic (only Deny enforcement is suppressed)."""


class RaiEgressRuleActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of action an egress rule takes when it matches."""

    ALLOW = "Allow"
    """Allow the matched traffic."""
    DENY = "Deny"
    """Deny the matched traffic."""
    TRANSFORM = "Transform"
    """Forward the matched traffic after applying header transforms. Requires at least one header."""
    REWRITE = "Rewrite"
    """Redirect the matched traffic to a new destination, optionally applying header transforms.
    Requires a rewrite target."""


class RaiEgressRuleType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of an egress rule, determining what kind of traffic matching it performs."""

    FQDN = "Fqdn"
    """Fully qualified domain name (FQDN) based rule matching on host and path patterns."""


class RaiEgressScheme(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """URL scheme for rewrite targets. Only HTTP and HTTPS are supported."""

    HTTP = "http"
    """HTTP scheme."""
    HTTPS = "https"
    """HTTPS scheme."""


class RaiPolicyContentSource(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Content source to apply the Content Filters."""

    PROMPT = "Prompt"
    """PROMPT."""
    COMPLETION = "Completion"
    """COMPLETION."""
    PRE_TOOL_CALL = "PreToolCall"
    """PRE_TOOL_CALL."""
    POST_TOOL_CALL = "PostToolCall"
    """POST_TOOL_CALL."""
    PRE_RUN = "PreRun"
    """PRE_RUN."""
    POST_RUN = "PostRun"
    """POST_RUN."""


class RaiPolicyMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Rai policy mode. The enum value mapping is as below: Default = 0, Deferred=1, Blocking=2,
    Asynchronous_filter =3. Please use 'Asynchronous_filter' after 2025-06-01. It is the same as
    'Deferred' in previous version.
    """

    DEFAULT = "Default"
    """DEFAULT."""
    DEFERRED = "Deferred"
    """DEFERRED."""
    BLOCKING = "Blocking"
    """BLOCKING."""
    ASYNCHRONOUS_FILTER = "Asynchronous_filter"
    """ASYNCHRONOUS_FILTER."""


class RaiPolicyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Content Filters policy type."""

    USER_MANAGED = "UserManaged"
    """USER_MANAGED."""
    SYSTEM_MANAGED = "SystemManaged"
    """SYSTEM_MANAGED."""


class ResourceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The identity type."""

    NONE = "None"
    """NONE."""
    SYSTEM_ASSIGNED = "SystemAssigned"
    """SYSTEM_ASSIGNED."""
    USER_ASSIGNED = "UserAssigned"
    """USER_ASSIGNED."""
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned, UserAssigned"
    """SYSTEM_ASSIGNED_USER_ASSIGNED."""


class ResourceSkuRestrictionsReasonCode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The reason for restriction."""

    QUOTA_ID = "QuotaId"
    """QUOTA_ID."""
    NOT_AVAILABLE_FOR_SUBSCRIPTION = "NotAvailableForSubscription"
    """NOT_AVAILABLE_FOR_SUBSCRIPTION."""


class ResourceSkuRestrictionsType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of restrictions."""

    LOCATION = "Location"
    """LOCATION."""
    ZONE = "Zone"
    """ZONE."""


class RoutingMethods(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Multiregion routing methods."""

    PRIORITY = "Priority"
    """PRIORITY."""
    WEIGHTED = "Weighted"
    """WEIGHTED."""
    PERFORMANCE = "Performance"
    """PERFORMANCE."""


class RoutingMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The model-router routing mode that determines how requests are distributed across models."""

    COST = "cost"
    """Route requests to minimize cost while meeting performance requirements."""
    BALANCED = "balanced"
    """Balance cost and quality when routing requests across models."""
    QUALITY = "quality"
    """Route requests to maximize quality regardless of cost."""


class RuleAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action enum for a managed network outbound rule."""

    ALLOW = "Allow"
    """ALLOW."""
    DENY = "Deny"
    """DENY."""


class RuleCategory(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Category of a managed network Outbound Rule of a cognitive services account."""

    REQUIRED = "Required"
    """REQUIRED."""
    RECOMMENDED = "Recommended"
    """RECOMMENDED."""
    USER_DEFINED = "UserDefined"
    """USER_DEFINED."""
    DEPENDENCY = "Dependency"
    """DEPENDENCY."""


class RuleStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of a managed network Outbound Rule of a cognitive services account."""

    INACTIVE = "Inactive"
    """INACTIVE."""
    ACTIVE = "Active"
    """ACTIVE."""
    PROVISIONING = "Provisioning"
    """PROVISIONING."""
    DELETING = "Deleting"
    """DELETING."""
    FAILED = "Failed"
    """FAILED."""


class RuleType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of a managed network Outbound Rule of a cognitive services account."""

    FQDN = "FQDN"
    """FQDN."""
    PRIVATE_ENDPOINT = "PrivateEndpoint"
    """PRIVATE_ENDPOINT."""
    SERVICE_TAG = "ServiceTag"
    """SERVICE_TAG."""


class ScenarioType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies what features in AI Foundry network injection applies to. Currently only supports
    'agent' for agent scenarios. 'none' means no network injection.
    """

    NONE = "none"
    """NONE."""
    AGENT = "agent"
    """AGENT."""


class ServiceTier(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The service tier for the deployment. Determines the pricing and performance level for request
    processing. Use 'Default' for standard pricing or 'Priority' for higher-priority processing
    with premium pricing. Note: Pause operations are only supported on Standard, DataZoneStandard,
    and GlobalStandard SKUs.
    """

    DEFAULT = "Default"
    """Default service tier meaning the request will be processed with the standard pricing and
    performance for the selected model."""
    PRIORITY = "Priority"
    """Priority service tier meaning the request will be processed with higher pricing and performance
    for the selected model."""


class SkuTier(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """This field is required to be implemented by the Resource Provider if the service has more than
    one tier, but is not required on a PUT.
    """

    FREE = "Free"
    """FREE."""
    BASIC = "Basic"
    """BASIC."""
    STANDARD = "Standard"
    """STANDARD."""
    PREMIUM = "Premium"
    """PREMIUM."""
    ENTERPRISE = "Enterprise"
    """ENTERPRISE."""


class TierUpgradePolicy(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets the tier upgrade policy for the subscription."""

    ONCE_UPGRADE_IS_AVAILABLE = "OnceUpgradeIsAvailable"
    """ONCE_UPGRADE_IS_AVAILABLE."""
    NO_AUTO_UPGRADE = "NoAutoUpgrade"
    """NO_AUTO_UPGRADE."""


class TrafficRoutingProtocol(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Traffic routing protocol, used to distribute an application's inbound traffic to its
    deployments.
    """

    FIXED_RATIO = "FixedRatio"
    """Percentage based routing."""


class UnitType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The unit of the metric."""

    COUNT = "Count"
    """COUNT."""
    BYTES = "Bytes"
    """BYTES."""
    SECONDS = "Seconds"
    """SECONDS."""
    PERCENT = "Percent"
    """PERCENT."""
    COUNT_PER_SECOND = "CountPerSecond"
    """COUNT_PER_SECOND."""
    BYTES_PER_SECOND = "BytesPerSecond"
    """BYTES_PER_SECOND."""
    MILLISECONDS = "Milliseconds"
    """MILLISECONDS."""


class UpgradeAvailabilityStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies whether an upgrade to the next quota tier is available."""

    AVAILABLE = "Available"
    """AVAILABLE."""
    NOT_AVAILABLE = "NotAvailable"
    """NOT_AVAILABLE."""


class VmPriority(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """VM priority for a compute pool."""

    REGULAR = "Regular"
    """Regular VM priority."""
    LOW_PRIORITY = "LowPriority"
    """Low-priority VM."""
